import * as PIXI from "pixi.js";
export declare type Point = {
    x: number;
    y: number;
};
export declare type Rectangle = Point & {
    width: number;
    height: number;
};
export declare type Bounds = Rectangle;
export declare type Nested<T> = T | Array<Nested<T>>;
export declare type SplitStyle = "words" | "characters";
export declare type SpriteReference = PIXI.Sprite;
export declare type ImageMap = Record<string, SpriteReference>;
export interface TaggedTextOptions {
    debug?: boolean;
    debugConsole?: boolean;
    splitStyle?: SplitStyle;
    imgMap?: ImageMap;
    skipUpdates?: boolean;
    skipDraw?: boolean;
    drawWhitespace?: boolean;
}
export declare const IMG_SRC_PROPERTY = "imgSrc";
export declare const IMG_DISPLAY_PROPERTY = "imgDisplay";
export declare type VAlign = "top" | "middle" | "bottom" | "baseline" | number;
export declare type Align = "left" | "right" | "center" | "justify";
export declare type Color = string | number;
export declare type Fill = Color | string[] | number[] | CanvasGradient | CanvasPattern;
export declare type ImageDisplayMode = "icon" | "block" | "inline";
export declare type ImageSource = string;
export declare type ImageDimensionPercentage = string;
export declare type ImageDimension = number | string | ImageDimensionPercentage;
export interface TextStyle extends Record<string, unknown>, Partial<PIXI.TextStyle> {
    align?: Align;
}
export interface ImageStyles {
    [IMG_SRC_PROPERTY]?: ImageSource;
    [IMG_DISPLAY_PROPERTY]?: ImageDisplayMode;
    imgScale?: ImageDimensionPercentage;
    imgScaleX?: ImageDimensionPercentage;
    imgScaleY?: ImageDimensionPercentage;
    imgWidth?: ImageDimension;
    imgHeight?: ImageDimension;
}
export interface TextStyleExtended extends TextStyle, ImageStyles {
    lineSpacing?: number;
    valign?: VAlign;
}
export declare type TextStyleSet = Record<string, TextStyleExtended>;
declare type TagName = string;
declare type AttributeName = string;
declare type AttributeValue = string | number;
export declare type AttributesList = Record<AttributeName, AttributeValue>;
export interface TagWithAttributes {
    tagName: string;
    attributes: AttributesList;
}
export interface TagMatchData extends TagWithAttributes {
    tag: string;
    isOpening: boolean;
    index: number;
}
export declare type TagStack = TagMatchData[];
export declare type NewlineToken = "\n";
export declare type WhitespaceToken = " " | "\t" | NewlineToken;
export declare type TextToken = string;
export declare type SpriteToken = PIXI.Sprite;
export interface CompositeToken<T extends Token = Token> {
    children: T[];
}
export declare type Token = TextToken | CompositeToken | SpriteToken;
export declare type Tokens = CompositeToken;
export interface TagToken extends CompositeToken<TagToken | TextToken> {
    tag?: TagName;
    attributes?: AttributesList;
}
export declare type TagTokens = TagToken;
export interface StyledToken extends CompositeToken<StyledToken | TextToken | SpriteToken> {
    style: TextStyleExtended;
    tags: string;
}
export declare type StyledTokens = StyledToken;
export interface FinalToken {
    content: TextToken | SpriteToken;
    bounds: Rectangle;
    fontProperties: PIXI.IFontMetrics;
    style: TextStyleExtended;
    tags: string;
}
export declare const createEmptyFinalToken: () => FinalToken;
export declare type WordToken = FinalToken[];
export declare type LineToken = WordToken[];
export declare type ParagraphToken = LineToken[];
export interface SpriteFinalToken extends FinalToken {
    content: SpriteToken;
}
export interface TextFinalToken extends FinalToken {
    content: TextToken;
}
export interface WhitespaceFinalToken extends TextFinalToken {
    content: WhitespaceToken;
}
export interface NewlineFinalToken extends TextFinalToken {
    content: NewlineToken;
}
export declare const isWhitespace: (s: string) => s is WhitespaceToken;
export declare const isNewline: (s: string) => s is "\n";
export declare const _isSpriteToken: (t: FinalToken) => t is SpriteFinalToken;
export declare const isSpriteToken: (nested: Nested<FinalToken>) => boolean;
export declare const _isTextToken: (t: FinalToken) => t is TextFinalToken;
export declare const isTextToken: (nested: Nested<FinalToken>) => boolean;
export declare const _isWhitespaceToken: (t: FinalToken) => t is WhitespaceFinalToken;
export declare const isWhitespaceToken: (nested: Nested<FinalToken>) => boolean;
export declare const _isNewlineToken: (t: FinalToken) => t is NewlineFinalToken;
export declare const isNewlineToken: (nested: Nested<FinalToken>) => boolean;
export declare const isNotWhitespaceToken: (input: Nested<FinalToken>) => boolean;
export declare const isEmptyObject: <T extends unknown>(a: T) => boolean;
export {};
